@@ -481,7 +481,7 @@ package String::PictureFormat;
 use strict;
 #use warnings;
 use vars qw(@ISA @EXPORT $VERSION);
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 use Time::Local;
 
@@ -993,7 +993,6 @@ sub unfmt {
 			return wantarray ? ($v, $leni, $justify) : $v;
 		} elsif ($pic =~ s#^\^##o) {  #DATE-CONVERSION
 			eval 'use Date::Fmtstr2time; $haveFmtstr2time = 1; 1'  unless ($haveFmtstr2time);
-			use Date::Fmtstr2time; $haveFmtstr2time = 1;
 			my $t = '';
 			if ($haveFmtstr2time) {   #CONVERT TO A PERL "TIME" USING Fmtstr2time IF IT'S AVAILABLE:
 				$t = str2time($v, $pic);
@@ -1008,7 +1007,7 @@ sub unfmt {
 				$t =~ s/^    /'20'.substr($v,index($pic,'yy'),2)/e;
 				$t =~ s/  $/01/;
 				$t =~ s/ /$errchar/g;
-				foreach my $i (qw(HH mi ss)) {
+				foreach my $i (qw(HH hh mi ss)) {
 					$t .= substr($v,index($pic,$i),length($i))  if (index($pic,$i) > 0);
 				}
 				$t =~ s/[^0-9 ]/ /go;
@@ -1062,7 +1061,7 @@ sub unfmt {
 				$v .= $1  unless ($ops->{'-suffix'} =~ /no/io);
 				return wantarray ? ($v, 0, '<') : $v;
 			}
-			$suffix = $1  if ($pic =~ s/([^<|>.]+)$//);
+			$suffix = $1  if ($pic =~ s/([^<|>.]+)$//o);
 			my ($special, $isneg, $t);
 			my $commatize = 0;
 			while ($pic =~ s/^([^\d\<\|\>\.])//o) {  #STRIP OFF ALL CHARS BEFORE <, >, |, OR DIGIT AS "FLOATING CHARS".
@@ -1247,7 +1246,7 @@ sub fmtsiz {
 			$pic =~ s/\x02/\(/go;			
 			(my $t = $v) =~ s/\D//go;
 			return length($pic);
-		} elsif ($pic =~ m#^(?:s|tr)\W#) {         #REGEX SUBSTITUTION (@s/foo/bar/)
+		} elsif ($pic =~ m#^(?:s|tr)\W#o) {         #REGEX SUBSTITUTION (@s/foo/bar/)
 			return 0;
 		} elsif ($pic =~ /^[a-zA-Z_]+/o) {     #USER-SUPPLIED FUNCTION (@foo('*'))
 			return 0;
@@ -1320,13 +1319,13 @@ sub fmtjust {
 			return '<';
 		} elsif ($pic =~ s#^\^##o) {         #DATE-CONVERSION
 			return '<';
-		} elsif ($pic =~ m#^(?:s|tr)\W#) {          #REGEX SUBSTITUTION (@s/foo/bar/)
+		} elsif ($pic =~ m#^(?:s|tr)\W#o) {          #REGEX SUBSTITUTION (@s/foo/bar/)
 			return '<';
 		} elsif ($pic =~ /^[a-zA-Z_]+/o) {     #USER-SUPPLIED FUNCTION (@foo('*'))
 			return '<';
 		} else {                               #REGULAR STUFF, IE. @12>.>>)
 			return '<'  if ($pic =~ /^\*(.*)$/);
-			$suffix = $1  if ($pic =~ s/([^\<\|\>\.\^]+)$//);
+			$suffix = $1  if ($pic =~ s/([^\<\|\>\.\^]+)$//o);
 			my ($special, $float, $t);
 			my $commatize = 0;
 			while ($pic =~ s/^([^\d\<\|\>\.\^])//o) {  #STRIP OFF ALL CHARS BEFORE <, >, |, OR DIGIT AS "FLOATING CHARS".
@@ -1390,18 +1389,18 @@ sub fmtsuffix {
 			$suffix = $1  if ($pic =~ s#\Q$regexDelimiter\E(.*)$##);
 			return $suffix;
 		} elsif ($pic =~ s#^\^##o) {         #DATE-CONVERSION
-			$suffix = $1  if ($pic =~ s#\^(.*)$##);
+			$suffix = $1  if ($pic =~ s#\^(.*)$##o);
 			return $suffix;
 		} elsif ($pic =~ m#^(?:s|tr)(\W)#) {          #REGEX SUBSTITUTION (@s/foo/bar/)
 			my $regexDelimiter = $1;
 			$suffix = $1  if ($pic =~ s#([^$regexDelimiter]+)$##);
 			return $suffix;
 		} elsif ($pic =~ /^[a-zA-Z_]+/o) {     #USER-SUPPLIED FUNCTION (@foo('*'))
-			$suffix = $1  if ($pic =~ s/\)([^\)]*)$/\)/);
+			$suffix = $1  if ($pic =~ s/\)([^\)]*)$/\)/o);
 			return $suffix;
 		} else {                               #REGULAR STUFF, IE. @12>.>>)
 			return $1  if ($pic =~ /^\*(.*)$/);
-			$suffix = $1  if ($pic =~ s/([^<|>.]+)$//);
+			$suffix = $1  if ($pic =~ s/([^<|>.]+)$//o);
 			return $suffix;
 		}
 	} elsif ($pic =~ s/^\=//o) {    #FIELDS STARTING WITH "=" ARE TO BE WRAPPED TO MULTIPLE LINES AS NEEDED:
